gigasetelements-cli is a python based program which allows you to control your Gigaset Elements home security system. It comes with an easy to use CLI 
(command-line interface) suitable for direct use or cron jobs.
